@@ -84,11 +84,11 @@ class JustIntonationPitch(parameters.abc.Pitch):
     """Pitch that is defined by a frequency ratio and a reference pitch.
 
     :param ratio_or_exponents: The frequency ratio of the ``JustIntonationPitch``.
-        This can either be (A) a string that indicates the frequency ratio (for
-        instance: "1/1", "3/2", "9/2", etc.), or (B) a ``fractions.Fraction``
-        (or ``quicktions.Fraction``) object that indicates the frequency ratio
-        (for instance: ``fractions.Fraction(3, 2)``, ``fractions.Fraction(7, 4)``)
-        or (C) an Iterable that is filled with integer that represents the exponents
+        This can either be a string that indicates the frequency ratio (for
+        instance: "1/1", "3/2", "9/2", etc.), or a ``fractions.Fraction``
+        object that indicates the frequency ratio (for instance:
+        ``fractions.Fraction(3, 2)``, ``fractions.Fraction(7, 4)``) or
+        an Iterable that is filled with integer that represents the exponents
         of the respective prime numbers of the decomposed frequency ratio. The prime
         numbers are rising and start with 2. Therefore the tuple ``(2, 0, -1)``
         would return the frequency ratio ``4/5`` because
@@ -100,6 +100,8 @@ class JustIntonationPitch(parameters.abc.Pitch):
     The resulting frequency is calculated by multiplying the frequency ratio
     with the respective reference pitch.
 
+    **Example:**
+
     >>> from mutwo.parameters import pitches
     >>> # 3 different variations of initialising the same pitch
     >>> pitches.JustIntonationPitch('3/2')
@@ -160,7 +162,7 @@ class JustIntonationPitch(parameters.abc.Pitch):
         until it is equal or bigger than 1 and smaller than border.
 
         Arguments:
-            * rratio: The Ratio, which shall be adjusted
+            * ratio: The Ratio, which shall be adjusted
             * border
         >>> ratio0 = fractions.Fraction(1, 3)
         >>> ratio1 = fractions.Fraction(8, 3)
@@ -324,6 +326,7 @@ class JustIntonationPitch(parameters.abc.Pitch):
                       ._exponents - Argument (see JustIntonationPitch._exponents).
             * primes-shift -> how many prime numbers shall be skipped
                             (see JustIntonationPitch.primes_shift)
+
         >>> myJustIntonationPitch0 = (1, 0, -1)
         >>> myJustIntonationPitch1 = (0, 2, 0)
         >>> myPrimes = (2, 3, 5)
@@ -343,8 +346,10 @@ class JustIntonationPitch(parameters.abc.Pitch):
     def _ratio_to_exponents(ratio: fractions.Fraction) -> tuple:
         r"""Transform a fractions.Fraction - Object to a vector of exponents.
 
-        Arguments are:
-            * ratio -> The fractions.Fraction, which shall be transformed
+        :param ratio: The fractions.Fraction, which shall be transformed
+
+        **Example:**
+
         >>> try:
         >>>     from quicktions import fractions.Fraction
         >>> except ImportError:
@@ -382,6 +387,8 @@ class JustIntonationPitch(parameters.abc.Pitch):
         Arguments:
             * num -> integer, whose _indigestibility value shall be calculated
 
+        **Example:**
+
         >>> JustIntonationPitch._indigestibility(1)
         0
         >>> JustIntonationPitch._indigestibility(2)
@@ -471,6 +478,8 @@ class JustIntonationPitch(parameters.abc.Pitch):
         Note the difference that the second version might be slightly
         more performant.
 
+        **Example:**
+
         >>> jip0 = JustIntonationPitch((-1, 1))
         >>> float(jip0)
         1.5
@@ -512,6 +521,8 @@ class JustIntonationPitch(parameters.abc.Pitch):
     def primes(self) -> tuple:
         r"""Return ascending list of primes, until the highest contained Prime.
 
+        **Example:**
+
         >>> jip0 = JustIntonationPitch((0, 1, 2))
         >>> jip0.exponents
         (2, 3, 5)
@@ -551,6 +562,8 @@ class JustIntonationPitch(parameters.abc.Pitch):
     def ratio(self) -> fractions.Fraction:
         """Return the JustIntonationPitch transformed to a Ratio.
 
+        **Example:**
+
         >>> jip0 = JustIntonationPitch((0, 0, 1,))
         >>> jip0.ratio
         fractions.Fraction(5, 4)
@@ -565,6 +578,8 @@ class JustIntonationPitch(parameters.abc.Pitch):
     def numerator(self) -> int:
         """Return the numerator of a JustIntonationPitch - object.
 
+        **Example:**
+
         >>> jip0 = JustIntonationPitch((0, -1,))
         >>> jip0.numerator
         1
@@ -578,7 +593,9 @@ class JustIntonationPitch(parameters.abc.Pitch):
 
     @property
     def denominator(self) -> int:
-        """Return the denominator of a JustIntonationPitch - object.
+        """Return the denominator of :class:`JustIntonationPitch`.
+
+        **Example:**
 
         >>> jip0 = JustIntonationPitch((0, 1,))
         >>> jip0.denominator
@@ -599,6 +616,8 @@ class JustIntonationPitch(parameters.abc.Pitch):
     def factorised(self) -> tuple:
         """Return factorised / decomposed version of itsef.
 
+        **Example:**
+
         >>> jip0 = JustIntonationPitch((0, 0, 1,))
         >>> jip0.factorised
         (2, 2, 5)
@@ -697,6 +716,8 @@ class JustIntonationPitch(parameters.abc.Pitch):
         positive number and False if the exponent is a
         negative number (utonality).
 
+        **Example:**
+
         >>> jip0 = JustIntonationPitch((-2. 1))
         >>> jip0.tonality
         True
@@ -725,12 +746,14 @@ class JustIntonationPitch(parameters.abc.Pitch):
     def harmonic(self) -> int:
         """Return the nth - harmonic / subharmonic the pitch may represent.
 
-        May be positive for harmonic and negative for
-        subharmonic pitches. If the return - value is 0,
-        the interval may occur neither between the first harmonic
-        and any other pitch of the harmonic scale nor
-        between the first subharmonic in the and any other
-        pitch of the subharmonic scale.
+        :return: May be positive for harmonic and negative for
+            subharmonic pitches. If the return - value is 0,
+            the interval may occur neither between the first harmonic
+            and any other pitch of the harmonic scale nor
+            between the first subharmonic in the and any other
+            pitch of the subharmonic scale.
+
+        **Example:**
 
         >>> jip0 = JustIntonationPitch((0, 1))
         >>> jip0.ratio
@@ -779,6 +802,9 @@ class JustIntonationPitch(parameters.abc.Pitch):
         A higher number means a less consonant interval /
         a more complicated harmony.
         euler(1/1) is definied as 1.
+
+        **Example:**
+
         >>> jip0 = JustIntonationPitch((0, 1,))
         >>> jip1 = JustIntonationPitch()
         >>> jip2 = JustIntonationPitch((0, 0, 1,))
@@ -808,6 +834,8 @@ class JustIntonationPitch(parameters.abc.Pitch):
 
         barlow(1/1) is definied as infinite.
 
+        **Example:**
+
         >>> jip0 = JustIntonationPitch((0, 1,))
         >>> jip1 = JustIntonationPitch()
         >>> jip2 = JustIntonationPitch((0, 0, 1,))
@@ -954,6 +982,27 @@ class JustIntonationPitch(parameters.abc.Pitch):
 
     @decorators.add_return_option
     def register(self, octave: int) -> typing.Optional["JustIntonationPitch"]:  # type: ignore
+        """Move :class:`JustIntonationPitch` to the given octave.
+
+        :param octave: 0 for the octave from 1/1 to 2/1, negative values for octaves
+            below 1/1 and positive values for octaves above 2/1.
+        :type octave: int
+
+        **Example:**
+
+        >>> from mutwo.parameters import pitches
+        >>> p = pitches.JustIntonationPitch('3/2')
+        >>> p.register(1)
+        >>> p
+        JustIntonationPitch(6/2)
+        >>> p.register(-1)
+        >>> p
+        JustIntonationPitch(3/4)
+        >>> p.register(0)
+        >>> p
+        JustIntonationPitch(3/2)
+        """
+
         normalized_just_intonation_pitch = self.normalize(mutate=False)  # type: ignore
         factor = 2 ** abs(octave)
         if octave < 1:
@@ -983,14 +1032,25 @@ class JustIntonationPitch(parameters.abc.Pitch):
             self.exponents = best[0].exponents
         else:
             raise NotImplementedError(
-                "Couldn't find closest register of '{}' to '{}'.".format(
-                    self, reference
-                )
+                f"Couldn't find closest register of '{self}' to '{reference}'."
             )
 
     @decorators.add_return_option
     def normalize(self, prime: int = 2) -> typing.Optional["JustIntonationPitch"]:  # type: ignore
-        """Normalize JustIntonationPitch."""
+        """Normalize :class:`JustIntonationPitch`.
+
+        :param prime: The normalization period (2 for octave,
+            3 for twelfth, ...). Default to 2.
+        :type prime: int
+
+        **Example:**
+
+        >>> from mutwo.parameters import pitches
+        >>> p = pitches.JustIntonationPitch('12/2')
+        >>> p.normalize()
+        >>> p
+        JustIntonationPitch(3/2)
+        """
         ratio = self.ratio
         adjusted = type(self)._adjust_ratio(ratio, prime)
         self.exponents = self._translate_ratio_or_fractions_argument_to_exponents(
@@ -1001,6 +1061,21 @@ class JustIntonationPitch(parameters.abc.Pitch):
     def inverse(  # type: ignore
         self, axis: typing.Optional["JustIntonationPitch"] = None
     ) -> typing.Optional["JustIntonationPitch"]:
+        """Inverse current pitch on given axis.
+
+        :param axis: The :class:`JustIntonationPitch` from which the
+            pitch shall be inversed.
+        :type axis: JustIntonationPitch, optional
+
+        **Example:**
+
+        >>> from mutwo.parameters import pitches
+        >>> p = pitches.JustIntonationPitch('3/2')
+        >>> p.inverse()
+        >>> p
+        JustIntonationPitch(2/3)
+        """
+
         if axis is None:
             exponents = tuple(map(lambda x: -x, self.exponents))
         else:
@@ -1012,14 +1087,82 @@ class JustIntonationPitch(parameters.abc.Pitch):
     def add(  # type: ignore
         self, other: "JustIntonationPitch"
     ) -> typing.Optional["JustIntonationPitch"]:
+        """Add :class:`JustIntonationPitch` to current pitch.
+
+        :param other: The :class:`JustIntonationPitch` to add to
+            the current pitch.
+
+        **Example:**
+
+        >>> from mutwo.parameters import pitches
+        >>> p = pitches.JustIntonationPitch('3/2')
+        >>> p.add(pitches.JustIntonationPitch('3/2'))
+        >>> p
+        JustIntonationPitch(9/4)
+        """
         self._math(other, operator.add)
 
     @decorators.add_return_option
     def subtract(  # type: ignore
         self, other: "JustIntonationPitch"
     ) -> typing.Optional["JustIntonationPitch"]:
+        """Subtract :class:`JustIntonationPitch` from current pitch.
+
+        :param other: The :class:`JustIntonationPitch` to subtract from
+            the current pitch.
+
+        **Example:**
+
+        >>> from mutwo.parameters import pitches
+        >>> p = pitches.JustIntonationPitch('9/4')
+        >>> p.subtract(pitches.JustIntonationPitch('3/2'))
+        >>> p
+        JustIntonationPitch(3/2)
+        """
+
         self._math(other, operator.sub)
 
+    @decorators.add_return_option
+    def intersection(
+        self, other: "JustIntonationPitch"
+    ) -> typing.Optional["JustIntonationPitch"]:
+        """Make intersection with other :class:`JustIntonationPitch`.
+
+        :param other: The :class:`JustIntonationPitch` to build the
+            intersection with.
+
+        **Example:**
+
+        >>> from mutwo.parameters import pitches
+        >>> p = pitches.JustIntonationPitch('5/3')
+        >>> p.intersection(pitches.JustIntonationPitch('7/6'))
+        >>> p
+        JustIntonationPitch(1/3)
+        """
+
+        def is_negative(number: int):
+            return number < 0
+
+        def intersect_exponents(exponents: typing.Tuple[int, int]) -> int:
+            intersected_exponent = 0
+
+            if 0 not in exponents:
+                are_negative = (is_negative(exponent) for exponent in exponents)
+                all_are_negative = all(are_negative)
+                all_are_positive = all(not boolean for boolean in are_negative)
+
+                if all_are_negative:
+                    intersected_exponent = max(exponents)
+                elif all_are_positive:
+                    intersected_exponent = min(exponents)
+
+            return intersected_exponent
+
+        intersected_exponents = tuple(
+            map(intersect_exponents, zip(self.exponents, other.exponents))
+        )
+        self.exponents = intersected_exponents
+
 
 class EqualDividedOctavePitch(parameters.abc.Pitch):
     """Pitch that is tuned to an Equal divided octave tuning system.
